You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@groovy.apache.org by su...@apache.org on 2021/06/17 08:39:16 UTC

[groovy] branch danielsun/tweak-build updated: Disable `IllegalAccessTests` for JDK16+

This is an automated email from the ASF dual-hosted git repository.

sunlan pushed a commit to branch danielsun/tweak-build
in repository https://gitbox.apache.org/repos/asf/groovy.git


The following commit(s) were added to refs/heads/danielsun/tweak-build by this push:
     new f539d24  Disable `IllegalAccessTests` for JDK16+
f539d24 is described below

commit f539d249b72d2f71d07cf5b2f858aed768853f7f
Author: Daniel Sun <su...@apache.org>
AuthorDate: Thu Jun 17 16:39:02 2021 +0800

    Disable `IllegalAccessTests` for JDK16+
---
 src/test/groovy/IllegalAccessTests.groovy | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/test/groovy/IllegalAccessTests.groovy b/src/test/groovy/IllegalAccessTests.groovy
index f0d1192..ceb5fca 100644
--- a/src/test/groovy/IllegalAccessTests.groovy
+++ b/src/test/groovy/IllegalAccessTests.groovy
@@ -30,14 +30,14 @@ import static org.junit.Assume.assumeTrue
  * Java via means such as reflection.
  *
  * In JDK versions < 9, Groovy supports permissive access and no warnings are given by the JDK.
  * In JDK versions >= 9, Groovy supports permissive access but the JDK gives illegal access warnings.
  * At some point, the JDK may further restrict permissive access and Groovy's support for this feature may be limited.
  */
 final class IllegalAccessTests {
 
     @Before
     void setUp() {
-        assumeTrue(isAtLeastJdk('9.0') && !Boolean.getBoolean('groovy.force.illegal.access'))
+        assumeTrue(!isAtLeastJdk('16.0') && isAtLeastJdk('9.0') && !Boolean.getBoolean('groovy.force.illegal.access'))
     }
 
     @Test
@@ -30,14 +30,14 @@ import static org.junit.Assume.assumeTrue
  *
  * In JDK versions < 9, Groovy supports permissive access and no warnings are given by the JDK.
- * In JDK versions >= 9, Groovy supports permissive access but the JDK gives illegal access warnings.
+ * In 9 <= JDK versions < 16, Groovy supports permissive access but the JDK gives illegal access warnings.
  * At some point, the JDK may further restrict permissive access and Groovy's support for this feature may be limited.
  */